@@ -94,13 +94,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 es-apply-settings.pl - Run to apply a JSON list of settings to indexes matching a pattern
 
 =head1 VERSION
 
-version 2.2
+version 2.3
 
 =head1 SYNOPSIS
 
@@ -112,6 +114,16 @@ Options:
     --manual            print full manual
     --close             Close the index, apply settings, and re-open the index
 
+From App::ElasticSearch::Utilities:
+
+    --local         Use localhost as the elasticsearch host
+    --host          ElasticSearch host to connect to
+    --port          HTTP port for your cluster
+    --index         Index to run commands against
+    --base          For daily indexes, reference only those starting with "logstash"
+                     (same as --pattern logstash-* or logstash-DATE)
+    --pattern       Use a pattern to operate on the indexes
+
 From CLI::Helpers:
 
     --color             Boolean, enable/disable color, default use git settings
