@@ -144,6 +144,7 @@ my $duration = 0;
 my $displayed = 0;
 my $header=0;
 my $age = undef;
+my %last_batch_id=();
 
 while( !$DONE || @AGES ) {
     $age = @AGES ? shift @AGES : $age;
@@ -160,7 +161,8 @@ while( !$DONE || @AGES ) {
             uri_param => {
                 timeout     => '10s',
                 scroll      => '30s',
-            }
+            },
+            method => 'POST',
         },
         # Search Body
         {
@@ -180,8 +182,9 @@ while( !$DONE || @AGES ) {
     $header++ == 0 && @SHOW && output({color=>'cyan'}, join("\t", @always,@SHOW));
     while( $result || !$DONE ) {
         my $hits = ref $result->{hits}{hits} eq 'ARRAY' ? $result->{hits}{hits} : [];
-        my $facets = exists $result->{facets} ? $result->{facets}{top}{terms} : [];
 
+        # Handle Faceting
+        my $facets = exists $result->{facets} ? $result->{facets}{top}{terms} : [];
         if( @$facets ) {
             print "$facet_header\n";
             for my $facet ( @$facets ) {
@@ -190,8 +193,16 @@ while( !$DONE || @AGES ) {
             last;
         }
 
+        # Reset the last batch ID if we have new data
+        %last_batch_id = () if @{$hits} > 0 && $last_hit_ts ne $hits->[-1]->{_source}{'@timestamp'};
+        debug({color=>'magenta'}, "+ ID cache is now empty.") unless keys %last_batch_id;
+
         foreach my $hit (@{ $hits }) {
+            # Skip if we've seen this record
+            next if exists $last_batch_id{$hit->{_id}};
+
             $last_hit_ts = $hit->{_source}{'@timestamp'};
+            $last_batch_id{$hit->{_id}}=1;
             my $record = {};
             if( @SHOW ) {
                 foreach my $f (@always) {
@@ -315,13 +326,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 es-search.pl - Provides a CLI for quick searches of data in ElasticSearch daily indexes
 
 =head1 VERSION
 
-version 2.2
+version 2.3
 
 =head1 SYNOPSIS
 
@@ -341,6 +354,16 @@ Options:
     --desc              Sort by descending timestamp (Default)
     --fields            Display the field list for this index!
 
+From App::ElasticSearch::Utilities:
+
+    --local         Use localhost as the elasticsearch host
+    --host          ElasticSearch host to connect to
+    --port          HTTP port for your cluster
+    --index         Index to run commands against
+    --base          For daily indexes, reference only those starting with "logstash"
+                     (same as --pattern logstash-* or logstash-DATE)
+    --pattern       Use a pattern to operate on the indexes
+
 From CLI::Helpers:
 
     --color             Boolean, enable/disable color, default use git settings
